@@ -1,5 +1,5 @@
-from .modelling_logic import create_signature_model
 from .models import SignatureModel
+from .parsing import create_signature_model
 from .utils import get_signature_model
 
 __all__ = ("create_signature_model", "SignatureModel", "get_signature_model")
